# Command Line Interface

The simplest usage of the command line interface is just
to run

```bash
roboherd run
```

!!! info
    The watch and register commands require you to install
    `roboherd[dev]`.

::: mkdocs-click
    :module: roboherd.__main__
    :command: main
    :prog_name: roboherd
    :depth: 2
